import { useState } from 'react'
import { Box, Button, CircularProgress } from '@mui/material'
import { DataGrid, GridColDef } from '@mui/x-data-grid'
import { useRoles } from '../hooks/swrHooks'
import CreateRoleModal from '../components/modals/CreateRoleModal'

export default function Roles() {
  const { roles, isError, isLoading } = useRoles()

  const [open, setOpen] = useState(false)

  const columns: GridColDef[] = [
    { field: 'id', headerName: 'ID', type: "number", width: 70 },
    { field: 'name', headerName: 'Название', width: 90, editable: true },
    { field: 'description', headerName: 'Описание', width: 90, editable: true },
  ];

  if (isError) return <div>Произошла ошибка при получении данных.</div>
  if (isLoading) return <CircularProgress />

  return (
    <Box sx={{
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'flex-start',
      gap: '16px',
      flexGrow: 1
    }}>
      <Button onClick={() => setOpen(true)}>
        Добавить роль
      </Button>

      <CreateRoleModal
        open={open}
        setOpen={setOpen}
      />

      <DataGrid
        autoHeight
        style={{ width: "100%" }}
        rows={roles}
        columns={columns}
        initialState={{
          pagination: {
            paginationModel: { page: 0, pageSize: 10 },
          },
        }}
        pageSizeOptions={[10, 20, 50, 100]}
        disableRowSelectionOnClick

        processRowUpdate={(updatedRow, originalRow) => {
          console.log(updatedRow)
          return updatedRow
        }}

        onProcessRowUpdateError={(error) => {
          console.log(error)
        }}
      />
    </Box>
  )
}